quantizationtools.Quantizer
===========================

.. abjad-lineage:: abjad.tools.quantizationtools.Quantizer.Quantizer.Quantizer

.. autoclass:: abjad.tools.quantizationtools.Quantizer.Quantizer.Quantizer
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.quantizationtools.Quantizer.Quantizer.Quantizer.storage_format
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.quantizationtools.Quantizer.Quantizer.Quantizer.__call__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.Quantizer.Quantizer.Quantizer.__eq__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.Quantizer.Quantizer.Quantizer.__ge__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.Quantizer.Quantizer.Quantizer.__gt__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.Quantizer.Quantizer.Quantizer.__le__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.Quantizer.Quantizer.Quantizer.__lt__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.Quantizer.Quantizer.Quantizer.__ne__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.Quantizer.Quantizer.Quantizer.__repr__
   :noindex:
